--- NewEnumWizardPage.java	Thu Aug  6 14:20:37 2009
+++ NewInterfaceWizardPage.java	Thu Aug  6 14:20:53 2009
@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2008 IBM Corporation and others.
+ * Copyright (c) 2000, 2008 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -27,29 +27,28 @@
 import org.eclipse.jdt.internal.ui.wizards.NewWizardMessages;
 
 /**
  * Wizard page to create a new enum type.
  * <p>
  * Note: This class is not intended to be subclassed, but clients can instantiate.
  * To implement a different kind of a new enum wizard page, extend <code>NewTypeWizardPage</code>.
  * </p>
  *
- * @since 3.1
+ * @since 2.0
  *
  * @noextend This class is not intended to be subclassed by clients.
  */
-public class NewEnumWizardPage extends NewTypeWizardPage {
+public class NewInterfaceWizardPage extends NewTypeWizardPage {
 
-    private final static String PAGE_NAME= "NewEnumWizardPage"; //$NON-NLS-1$
-    private final static int TYPE = NewTypeWizardPage.ENUM_TYPE;
+	private final static String PAGE_NAME= "NewInterfaceWizardPage"; //$NON-NLS-1$
 
 	/**
-	 * Create a new <code>NewEnumWizardPage</code>
+	 * Create a new <code>NewInterfaceWizardPage</code>
 	 */
-	public NewEnumWizardPage() {
-		super(TYPE, PAGE_NAME);
+	public NewInterfaceWizardPage() {
+		super(false, PAGE_NAME);
 
-		setTitle(NewWizardMessages.NewEnumWizardPage_title);
-		setDescription(NewWizardMessages.NewEnumWizardPage_description);
+		setTitle(NewWizardMessages.NewInterfaceWizardPage_title);
+		setDescription(NewWizardMessages.NewInterfaceWizardPage_description);
 	}
 
 	// -------- Initialization ---------
@@ -62,11 +61,10 @@
 	 * @param selection used to initialize the fields
 	 */
 	public void init(IStructuredSelection selection) {
-	    IJavaElement jelem= getInitialJavaElement(selection);
+		IJavaElement jelem= getInitialJavaElement(selection);
 
 		initContainerPage(jelem);
 		initTypePage(jelem);
-
 		doStatusUpdate();
 	}
 
@@ -131,7 +129,7 @@
 		setControl(composite);
 
 		Dialog.applyDialogFont(composite);
-		PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, IJavaHelpContextIds.NEW_ENUM_WIZARD_PAGE);
+		PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, IJavaHelpContextIds.NEW_INTERFACE_WIZARD_PAGE);
 	}
 
 	/*
@@ -27,29 +27,28 @@
 
 /**
- * Wizard page to create a new enum type.
+ * Wizard page to create a new interface.
  * <p>
  * Note: This class is not intended to be subclassed, but clients can instantiate.
@@ -27,29 +27,28 @@
  * <p>
  * Note: This class is not intended to be subclassed, but clients can instantiate.
- * To implement a different kind of a new enum wizard page, extend <code>NewTypeWizardPage</code>.
+ * To implement a different kind of a new interface wizard page, extend <code>NewTypeWizardPage</code>.
  * </p>
  *
